import kuto
from kuto import AdrElem


class HomePage(kuto.Page):
    """首页"""
    ad = AdrElem(resourceId='com.qizhidao.clientapp:id/bottom_btn')
    my = AdrElem(text='我的')
    setting = AdrElem(resourceId='com.qizhidao.clientapp:id/me_top_bar_setting_iv')


class TestSearch(kuto.TestCase):

    def start(self):
        self.page = HomePage(self.driver)

    def test_go_setting(self):
        self.page.ad.click_exists(timeout=5)
        self.page.my.click()
        self.page.setting.click()


if __name__ == '__main__':
    kuto.main(
        platform='android',
        deviceId='UJK0220521066836',
        pkgName='com.qizhidao.clientapp'
    )




"""
@Author: kang.yang
@Date: 2023/5/17 11:05
"""
import pyautogui

import kuto
from kuto import WebElem

from demo.tests.test_web import LoginFunc


def upload_file(file_path):
    pyautogui.write(file_path)
    pyautogui.press('enter', 3)


class BatchSearchPage(kuto.Page):
    uploadBtn = WebElem(css='#__layout > div > div.search-advance-container_wraper > div > div.search-container '
                            '> div > div:nth-child(1) > div.left-footer > div.op-bar > div.upload-btn > span:nth-child(1)')
    matchBtn = WebElem(css='#__layout > div > div.search-advance-container_wraper > div > div.search-container > div '
                           '> div:nth-child(1) > div.left-footer > div.op-bar > div.search-btn > button.el-button.el-button--primary')


class TestUpload(kuto.TestCase):

    def start(self):
        self.loginFunc = LoginFunc(self.driver)
        self.batchPage = BatchSearchPage(self.driver)

    def test_1(self):
        self.loginFunc.login_with_pwd("xxx", "xxx")
        self.open("https://patents.qizhidao.com/search/batchProcess?tab=advance")
        self.batchPage.uploadBtn.click()
        upload_file("/Users/UI/Downloads/upload.xlsx")
        self.batchPage.matchBtn.click()
        self.sleep(5)
        self.driver.screenshot("匹配结果")


if __name__ == '__main__':
    kuto.main(platform="web", host="https://www.qizhidao.com")



import kuto
from kuto import IosElem


class IndexPage(kuto.Page):
    ad = IosElem(text='close white big')
    my = IosElem(text='我的')
    setting = IosElem(text='settings navi')
    title = IosElem(text='设置')


class TestSearch(kuto.TestCase):
    def start(self):
        self.index_page = IndexPage(self.driver)

    def test_go_setting(self):
        self.index_page.ad.click_exists(timeout=5)
        self.index_page.my.click()
        self.index_page.setting.click()
        assert self.index_page.title.exists(timeout=3)


if __name__ == '__main__':
    kuto.main(
        platform='ios',
        deviceId='00008101-000E646A3C29003A',
        pkgName='com.qizhidao.company'
    )

